summaryrefslogtreecommitdiffstats
path: root/kalzium/src/eqchemview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalzium/src/eqchemview.h')
-rw-r--r--kalzium/src/eqchemview.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/kalzium/src/eqchemview.h b/kalzium/src/eqchemview.h
index 0e1ad686..85a9dda8 100644
--- a/kalzium/src/eqchemview.h
+++ b/kalzium/src/eqchemview.h
@@ -18,8 +18,8 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#ifndef _EQCHEMVIEW_H_
-#define _EQCHEMVIEW_H_
+#ifndef _ETQCHEMVIEW_H_
+#define _ETQCHEMVIEW_H_
#include <tqwidget.h>
#include <kdialogbase.h>
@@ -40,14 +40,15 @@ class KPushButton;
* @author Thomas Nagy <tnagy2^8\@yahoo.fr>
* @version 0.1
*/
-class eqchemView : public QWidget
+class eqchemView : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default constructor
*/
- eqchemView(TQWidget *parent);
+ eqchemView(TQWidget *tqparent);
/**
* Destructor
@@ -82,17 +83,18 @@ private:
/**
* @author Carsten Niehaus
*/
-class EQChemDialog : public KDialogBase
+class ETQChemDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* public constructor
*
* @param parent the parent widget
*/
- EQChemDialog( TQWidget *parent );
+ ETQChemDialog( TQWidget *tqparent );
private slots:
/**
@@ -101,4 +103,4 @@ class EQChemDialog : public KDialogBase
void slotHelp();
};
-#endif // _EQCHEMVIEW_H_
+#endif // _ETQCHEMVIEW_H_
@@ -82,17 +83,18 @@ private:
* public constructor
*
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
*/